@@ -1,3 +1,5 @@
+import copy
+
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
@@ -115,7 +117,7 @@ class QuantConvTranspose2d(nn.ConvTranspose2d):
                  a_bits=8,
                  w_bits=8):
         super(QuantConvTranspose2d, self).__init__(in_channels, out_channels, kernel_size, stride, padding, output_padding, 
-                         dilation, groups, bias, padding_mode)
+                                                   dilation, groups, bias, padding_mode)
         self.activation_quantizer = ActivationQuantizer(a_bits=a_bits)
         self.weight_quantizer = WeightQuantizer(w_bits=w_bits) 
 
@@ -137,4 +139,31 @@ class QuantLinear(nn.Linear):
         quant_weight = self.weight_quantizer(self.weight)
         output = F.linear(quant_input, quant_weight, self.bias)
         return output
-        
\ No newline at end of file
+
+def add_quant_op(module, a_bits=8, w_bits=8):
+    for name, child in module.named_children():
+        if isinstance(child, nn.Conv2d):
+            quant_conv = QuantConv2d(child.in_channels, child.out_channels,
+                                     child.kernel_size, stride=child.stride, padding=child.padding, dilation=child.dilation, groups=child.groups, bias=True, padding_mode=child.padding_mode, a_bits=a_bits, w_bits=w_bits)
+            quant_conv.weight.data = child.weight
+            quant_conv.bias.data = child.bias
+            module._modules[name] = quant_conv
+        elif isinstance(child, nn.ConvTranspose2d):
+            quant_conv_transpose = QuantConvTranspose2d(child.in_channels, child.out_channels,
+                                                        child.kernel_size, stride=child.stride, padding=child.padding, output_padding=child.output_padding, dilation=child.dilation, groups=child.groups, bias=True, padding_mode=child.padding_mode, a_bits=a_bits, w_bits=w_bits)
+            quant_conv_transpose.weight.data = child.weight
+            quant_conv_transpose.bias.data = child.bias
+            module._modules[name] = quant_conv_transpose
+        elif isinstance(child, nn.Linear):
+            quant_linear = QuantLinear(child.in_features, child.out_features, bias=True, a_bits=a_bits, w_bits=w_bits)
+            quant_linear.weight.data = child.weight
+            quant_linear.bias.data = child.bias
+            module._modules[name] = quant_linear
+        else:
+            add_quant_op(child, a_bits=a_bits, w_bits=w_bits)
+
+def prepare(model, inplace=False, a_bits=8, w_bits=8):
+    if not inplace:
+        model = copy.deepcopy(model)
+    add_quant_op(model, a_bits=a_bits, w_bits=w_bits)
+    return model
